poplar_isocc — poplar_isocc 1.0.0 documentation

# poplar_isocc

This package implements a method to validate a string against a reference list of country codes.

`poplar_isocc.` `is_valid_iso_cc`(code)

  Is `code` a valid ISO-3166 code?

  Parameters: | code (str) – country code to validate
  Return type: | bool
  Returns: | True if code is valid.

      from poplar_isocc import is_valid_iso_cc

      # Check if a code is valid.
      is_valid_iso_cc("CA")
          # returns True
      is_valid_iso_cc("ZZ")
          # returns False